@@ -235,26 +235,31 @@ print "\n\n\n\n\n\n\nWE SHOULD HAVE INSTALLED MARIADB=$stdout<==\n\n\n\n\n\n\n";
       last unless $stderr;
       ($stdout,$stderr)=$handle->cmd("sudo rm -rfv $pcre.tar.gz",'__display__');
    }
-   my $zlib='zlib-1.2.10';
+   ($stdout,$stderr)=$handle->cmd("sudo wget -qO- http://zlib.net/index.html");
+   my $zlib_ver=$stdout;
+   my $sha__256=$stdout;
+   $zlib_ver=~s/^.*? source code, version (\d+\.\d+\.\d+).*$/$1/s;
+   $sha__256=~s/^.*?SHA-256 hash [<]tt[>](.*?)[<][\/]tt[>].*$/$1/s;
    foreach my $count (1..3) {
-      ($stdout,$stderr)=$handle->cmd("sudo wget --random-wait --progress=dot ".
-         "http://zlib.net/$zlib.tar.gz",'__display__');
-      $checksum=
-         '8d7e9f698ce48787b6e1c67e6bff79e487303e66077e25cb9784ac8835978017';
+      ($stdout,$stderr)=$handle->cmd("wget --random-wait --progress=dot ".
+         "http://zlib.net/zlib-$zlib_ver.tar.gz",'__display__');
+      $checksum=$sha__256;
       ($stdout,$stderr)=$handle->cmd(
-         "sudo sha256sum -c - <<<\"$checksum $zlib.tar.gz\"",
+         "sha256sum -c - <<<\"$checksum zlib-$zlib_ver.tar.gz\"",
          '__display__');
       unless ($stderr) {
-         print(qq{ + CHECKSUM Test for $zlib *PASSED* \n});
+         print(qq{ + CHECKSUM Test for zlib-$zlib_ver *PASSED* \n});
          last
       } elsif ($count>=3) {
-         print "FATAL ERROR! : CHECKSUM Test for $zlib.tar.gz *FAILED* ",
+         print "FATAL ERROR! : CHECKSUM Test for zlib-$zlib_ver.tar.gz *FAILED* ",
                "after $count attempts\n";
          &Net::FullAuto::FA_Core::cleanup;
       }
-      ($stdout,$stderr)=$handle->cmd("sudo rm -rvf $zlib.tar.gz",'__display__');
+      ($stdout,$stderr)=$handle->cmd("rm -rvf zlib-$zlib_ver.tar.gz",
+         '__display__');
    }
-   ($stdout,$stderr)=$handle->cmd("sudo tar xvf $zlib.tar.gz",'__display__');
+   ($stdout,$stderr)=$handle->cmd("tar xvf zlib-$zlib_ver.tar.gz",
+      '__display__');
    my $ossl='openssl-1.0.2h';
    foreach my $count (1..3) {
       $checksum='577585f5f5d299c44dd3c993d3c0ac7a219e4949';
